@@ -105,15 +105,18 @@ path_is_dir (const gchar *path)
 
 
 gboolean
-dir_is_empty (const gchar *path)
+dir_is_empty (const char *path)
 {
 	DIR *dp;
-	int n;
+	int  n;
 
 	if (strcmp (path, "/") == 0)
 		return FALSE;
 
 	dp = opendir (path);
+	if (dp == NULL)
+		return TRUE;
+
 	n = 0;
 	while (readdir (dp) != NULL) {
 		n++;
@@ -128,6 +131,36 @@ dir_is_empty (const gchar *path)
 }
 
 
+gboolean
+dir_contains_one_object (const char *path)
+{
+	DIR *dp;
+	int  n;
+
+	if (path == NULL)
+		return FALSE;
+
+	if (strcmp (path, "/") == 0)
+		return FALSE;
+
+	dp = opendir (path);
+	if (dp == NULL)
+		return FALSE;
+
+	n = 0;
+	while (readdir (dp) != NULL) {
+		n++;
+		if (n > 3) {
+			closedir (dp);
+			return FALSE;
+		}
+	}
+	closedir (dp);
+
+	return TRUE;
+}
+
+
 /* Check whether the path_src is contained in path_dest */
 gboolean
 path_in_path (const char  *path_src,
@@ -438,6 +471,13 @@ is_mime_type (const char* type, const char* pattern) {
 }
 
 
+G_CONST_RETURN char*
+get_mime_type (const char  *filename)
+{
+	return gnome_vfs_get_mime_type_for_name (filename);
+}
+
+
 void
 path_list_free (GList *path_list)
 {
